@@ -46,6 +46,7 @@ from django.forms.util import ErrorList
 from django.shortcuts import render
 from django.template.loader import get_template
 from django.views.decorators import csrf
+from django.utils import timezone
 from django.utils.encoding import smart_unicode
 from askbot.utils.functions import generate_random_key, encode_jwt
 from django.utils.html import escape
@@ -120,7 +121,7 @@ def create_authenticated_user_account(
             openid_url = user_identifier,
             user = user,
             provider_name = login_provider_name,
-            last_used_timestamp = datetime.datetime.now()
+            last_used_timestamp = timezone.now()
         ).save()
 
     subscribe_form = askbot_forms.SimpleEmailSubscribeForm({'subscribe': 'y'})
@@ -605,7 +606,7 @@ def signin(request, template_name='authopenid/signin.html'):
                                 openid_url=email,
                                 user=user,
                                 provider_name='mozilla-persona',
-                                last_used_timestamp=datetime.datetime.now()
+                                last_used_timestamp=timezone.now()
                             ).save()
 
                     if user:
@@ -1034,7 +1035,7 @@ def finalize_generic_signin(
                     user=request.user,
                     provider_name=login_provider_name,
                     openid_url=user_identifier,
-                    last_used_timestamp=datetime.datetime.now()
+                    last_used_timestamp=timezone.now()
                 ).save()
                 return HttpResponseRedirect(redirect_url)
 
