@@ -10,6 +10,7 @@ from django.db import models
 from django.db.models import signals
 from django.template import Context
 from django.template.loader import get_template
+from django.utils import timezone
 from django.utils.importlib import import_module
 from django.utils.translation import ugettext as _
 from group_messaging.signals import response_created
@@ -233,7 +234,7 @@ class MessageManager(models.Manager):
                     senders_info=sender.username,
                     text=text,
                 )
-        now = datetime.datetime.now()
+        now = timezone.now()
         LastVisitTime.objects.create(message=message, user=sender, at=now)
         names = get_recipient_names(recipients)
         message.add_recipient_names_to_senders_info(recipients)
@@ -264,7 +265,7 @@ class MessageManager(models.Manager):
         #update headline
         message.root.headline = text[:MAX_HEADLINE_LENGTH]
         #mark last active timestamp for the root message
-        message.root.last_active_at = datetime.datetime.now()
+        message.root.last_active_at = timezone.now()
         #update senders info - stuff that is shown in the thread heading
         message.root.update_senders_info()
         #signal response as created, upon signal increment counters
@@ -388,7 +389,7 @@ class Message(models.Model):
 
         groups = self.recipients.all()
         recipients_users = User.objects.filter(
-                                    groups__in=groups
+                                    group_membership__group__in=groups
                                 ).exclude(
                                     id=self.sender.id
                                 ).distinct()
