@@ -3,6 +3,7 @@ from bs4 import BeautifulSoup
 from django.contrib.auth.models import User, Group
 from django.test import TestCase
 from group_messaging.models import LastVisitTime
+from django.utils import timezone
 from group_messaging.models import Message
 from group_messaging.models import MessageMemo
 from group_messaging.models import SenderList
@@ -11,7 +12,6 @@ from group_messaging.models import get_personal_group
 from group_messaging.models import get_unread_inbox_counter
 from group_messaging.views import ThreadsList
 from mock import Mock
-import datetime
 import time
 import urlparse
 
@@ -57,7 +57,7 @@ class GroupMessagingTests(TestCase):
                                                 user=user,
                                                 message=thread
                                             )
-        last_visit_time.at = datetime.datetime.now()
+        last_visit_time.at = timezone.now()
         last_visit_time.save()
         time.sleep(1.5)
         return last_visit_time
