@@ -10,6 +10,7 @@ from askbot.const import message_keys
 from django.conf import settings as django_settings
 from django.core.exceptions import PermissionDenied
 from django.forms.util import ErrorList
+from django.utils import timezone
 from django.utils.html import strip_tags
 from django.utils.datastructures import SortedDict
 from django.utils.translation import ugettext_lazy as _
@@ -1284,7 +1285,7 @@ class AnswerForm(PostAsSomeoneForm, PostPrivatelyForm):
             body_text = text,
             wiki = wiki,
             is_private = is_private,
-            timestamp = datetime.datetime.now(),
+            timestamp = timezone.now(),
             ip_addr=ip_addr
         )
 
