@@ -1,20 +1,20 @@
 from django.core.management.base import NoArgsCommand
 
-from askbot.models import User
+from askbot.models import UserProfile
 
 
 class Command(NoArgsCommand):
     def handle_noargs(self, *args, **kwargs):
         # Make sure all superusers have their status set to 'd'
-        fixed = (User.objects
-                 .filter(is_superuser=True)
+        fixed = (UserProfile.objects.
+                 .filter(auth_user__is_superuser=True)
                  .exclude(status='d')
                  .update(status='d'))
 
         # Make sure all normal users have their status not set to 'd'
-        fixed += (User.objects
+        fixed += (UserProfile.objects
                   .filter(status='d')
-                  .exclude(is_superuser=True)
+                  .exclude(pk__is_superuser=True)
                   .update(status='a'))
 
         self.stdout.write('Fixed the status of {0} users.'.format(fixed))
