@@ -1,5 +1,4 @@
 from collections import defaultdict
-import datetime
 import operator
 import logging
 
@@ -10,7 +9,8 @@ from django.contrib.auth.models import User
 from django.core import urlresolvers
 from django.db import models
 from django.utils import html as html_utils
-from django.utils.text import truncate_html_words
+from django.utils import timezone
+from django.utils.text import Truncator
 from django.utils.translation import activate as activate_language
 from django.utils.translation import get_language
 from django.utils.translation import ugettext as _
@@ -102,7 +102,7 @@ class PostQuerySet(models.query.QuerySet):
                 groups = [Group.objects.get_global_group()]
             else:
                 groups = user.get_groups()
-            return self.filter(groups__in = groups).distinct()
+            return self.filter(groups__in=groups).distinct()
         else:
             return self
 
@@ -172,7 +172,7 @@ class PostQuerySet(models.query.QuerySet):
                     question = question,
                     activity_type = activity_type
                 )
-                now = datetime.datetime.now()
+                now = timezone.now()
                 if now < activity.active_at + recurrence_delay:
                     continue
             except Activity.DoesNotExist:
@@ -182,7 +182,7 @@ class PostQuerySet(models.query.QuerySet):
                     activity_type = activity_type,
                     content_object = question,
                 )
-            activity.active_at = datetime.datetime.now()
+            activity.active_at = timezone.now()
             activity.save()
             question_list.append(question)
         return question_list
@@ -220,7 +220,7 @@ class PostManager(BaseQuerySetManager):
         return self.create_new(
                             None,#this post type is threadless
                             author,
-                            datetime.datetime.now(),
+                            timezone.now(),
                             text,
                             wiki = True,
                             post_type = 'tag_wiki'
@@ -401,7 +401,7 @@ class MockPost(object):
         self.id = 0
         self.author = MockUser()
         self.summary = ''
-        self.added_at = datetime.datetime.now()
+        self.added_at = timezone.now()
 
     def needs_moderation(self):
         return False
@@ -440,7 +440,7 @@ class Post(models.Model):
     groups = models.ManyToManyField('Group', through='PostToGroup', related_name = 'group_posts')#used for group-private posts
 
     author = models.ForeignKey(User, related_name='posts')
-    added_at = models.DateTimeField(default=datetime.datetime.now)
+    added_at = models.DateTimeField(default=timezone.now)
 
     #endorsed == accepted as best in the case of answer
     #use word 'endorsed' to differentiate from 'approved', which
@@ -715,9 +715,12 @@ class Post(models.Model):
     def get_moderators(self):
         """returns query set of users who are site administrators
         and moderators"""
-        user_filter = models.Q(is_superuser=True) | models.Q(status='m')
+        user_filter = models.Q(is_superuser=True) | models.Q(askbot_profile__status='m')
         #if askbot_settings.GROUPS_ENABLED:
-        #    user_filter = user_filter & models.Q(groups__in=self.groups.all())
+        #    post_groups = self.groups.all()
+        #    user_filter = user_filter & models.Q(
+        #                                group_membership__group__in=post_groups
+        #                            )
         return User.objects.filter(user_filter).distinct()
 
     def get_previous_answer(self, user=None):
@@ -813,12 +816,12 @@ class Post(models.Model):
 
         from askbot.models import Activity
         update_activity = Activity(
-                        user = updated_by,
-                        active_at = timestamp,
-                        content_object = self.current_revision,
-                        activity_type = activity_type,
-                        question = self.get_origin_post(),
-                        summary = summary
+                        user=updated_by,
+                        active_at=timestamp,
+                        content_object=self.current_revision,
+                        activity_type=activity_type,
+                        question=self.get_origin_post(),
+                        summary=summary
                     )
         update_activity.save()
 
@@ -828,10 +831,10 @@ class Post(models.Model):
         from askbot.models import Activity
         for u in notify_sets['for_mentions'] - notify_sets['for_inbox']:
             Activity.objects.create_new_mention(
-                                    mentioned_whom = u,
-                                    mentioned_in = self,
-                                    mentioned_by = updated_by,
-                                    mentioned_at = timestamp
+                                    mentioned_whom=u,
+                                    mentioned_in=self,
+                                    mentioned_by=updated_by,
+                                    mentioned_at=timestamp
                                 )
 
         for user in (notify_sets['for_inbox'] | notify_sets['for_mentions']):
@@ -936,7 +939,7 @@ class Post(models.Model):
             #for each revision of other post Ri
             #append content of Ri to R1 and use author
             new_text = orig_text + '\n\n' + rev.text
-            self.apply_edit(edited_at=datetime.datetime.now(),
+            self.apply_edit(edited_at=timezone.now(),
                             edited_by=user,
                             text=new_text,
                             comment=_('merged revision'),
@@ -1146,7 +1149,7 @@ class Post(models.Model):
         #the issue is that code blocks have few words
         #but very tall, while paragraphs can be dense on words
         #and fit into fewer lines
-        truncated = truncate_html_words(self.html, max_words)
+        truncated = Truncator(self.html).words(max_words, truncate=' ...', html=True)
         new_count = get_word_count(truncated)
         orig_count = get_word_count(self.html)
         if new_count + 1 < orig_count:
@@ -1224,7 +1227,7 @@ class Post(models.Model):
             ):
 
         if added_at is None:
-            added_at = datetime.datetime.now()
+            added_at = timezone.now()
         if None in (comment, user):
             raise Exception('arguments comment and user are required')
 
@@ -1275,16 +1278,16 @@ class Post(models.Model):
         #part 1 - find users who follow or not ignore the set of tags
         tag_names = self.get_tag_names()
         tag_selections = MarkedTag.objects.filter(
-            tag__name__in = tag_names,
-            tag__language_code=get_language(),
-            reason = tag_mark_reason
-        )
+                                        tag__name__in=tag_names,
+                                        tag__language_code=get_language(),
+                                        reason = tag_mark_reason
+                                    )
         subscribers = set(
             user_set_getter(
-                tag_selections__in = tag_selections
+                tag_selections__in=tag_selections
             ).filter(
-                email_tag_filter_strategy = email_tag_filter_strategy,
-                notification_subscriptions__in = subscription_records
+                askbot_profile__email_tag_filter_strategy=email_tag_filter_strategy,
+                notification_subscriptions__in=subscription_records
             )
         )
 
@@ -1296,22 +1299,22 @@ class Post(models.Model):
             #because we have to loop through the list of users
             #in python
             if tag_mark_reason == 'good':
-                empty_wildcard_filter = {'interesting_tags__exact': ''}
+                empty_wildcard_filter = {'askbot_profile__interesting_tags__exact': ''}
                 wildcard_tags_attribute = 'interesting_tags'
                 update_subscribers = lambda the_set, item: the_set.add(item)
             elif tag_mark_reason == 'bad':
-                empty_wildcard_filter = {'ignored_tags__exact': ''}
+                empty_wildcard_filter = {'askbot_profile__ignored_tags__exact': ''}
                 wildcard_tags_attribute = 'ignored_tags'
                 update_subscribers = lambda the_set, item: the_set.discard(item)
             elif tag_mark_reason == 'subscribed':
-                empty_wildcard_filter = {'subscribed_tags__exact': ''}
+                empty_wildcard_filter = {'askbot_profile__subscribed_tags__exact': ''}
                 wildcard_tags_attribute = 'subscribed_tags'
                 update_subscribers = lambda the_set, item: the_set.add(item)
 
             potential_wildcard_subscribers = User.objects.filter(
-                notification_subscriptions__in = subscription_records
+                notification_subscriptions__in=subscription_records
             ).filter(
-                email_tag_filter_strategy = email_tag_filter_strategy
+                askbot_profile__email_tag_filter_strategy=email_tag_filter_strategy
             ).exclude(
                 **empty_wildcard_filter #need this to limit size of the loop
             )
@@ -1340,13 +1343,13 @@ class Post(models.Model):
 
         from askbot.models.user import EmailFeedSetting
         global_subscriptions = EmailFeedSetting.objects.filter(
-            feed_type = 'q_all',
-            frequency = 'i'
+            feed_type='q_all',
+            frequency='i'
         )
 
         #segment of users who have tag filter turned off
         global_subscribers = User.objects.filter(
-            models.Q(email_tag_filter_strategy=const.INCLUDE_ALL)
+            models.Q(askbot_profile__email_tag_filter_strategy=const.INCLUDE_ALL)
             & models.Q(
                 notification_subscriptions__feed_type='q_all',
                 notification_subscriptions__frequency='i'
@@ -1361,8 +1364,8 @@ class Post(models.Model):
             good_mark_reason = 'good'
         subscriber_set.update(
             self.get_global_tag_based_subscribers(
-                subscription_records = global_subscriptions,
-                tag_mark_reason = good_mark_reason
+                subscription_records=global_subscriptions,
+                tag_mark_reason=good_mark_reason
             )
         )
 
@@ -1370,7 +1373,7 @@ class Post(models.Model):
         subscriber_set.update(
             self.get_global_tag_based_subscribers(
                 subscription_records = global_subscriptions,
-                tag_mark_reason = 'bad'
+                tag_mark_reason='bad'
             )
         )
         return subscriber_set
@@ -1378,9 +1381,9 @@ class Post(models.Model):
 
     def _qa__get_instant_notification_subscribers(
             self,
-            potential_subscribers = None,
-            mentioned_users = None,
-            exclude_list = None,
+            potential_subscribers=None,
+            mentioned_users=None,
+            exclude_list=None,
             ):
         """get list of users who have subscribed to
         receive instant notifications for a given post
@@ -1419,9 +1422,9 @@ class Post(models.Model):
         from askbot.models.user import EmailFeedSetting
         if mentioned_users:
             mention_subscribers = EmailFeedSetting.objects.filter_subscribers(
-                potential_subscribers = mentioned_users,
-                feed_type = 'm_and_c',
-                frequency = 'i'
+                potential_subscribers=mentioned_users,
+                feed_type='m_and_c',
+                frequency='i'
             )
             subscriber_set.update(mention_subscribers)
 
@@ -1436,9 +1439,9 @@ class Post(models.Model):
         #print 'question followers are ', [s for s in selective_subscribers]
         if selective_subscribers:
             selective_subscribers = EmailFeedSetting.objects.filter_subscribers(
-                potential_subscribers = selective_subscribers,
-                feed_type = 'q_sel',
-                frequency = 'i'
+                potential_subscribers=selective_subscribers,
+                feed_type='q_sel',
+                frequency='i'
             )
             subscriber_set.update(selective_subscribers)
             #print 'selective subscribers: ', selective_subscribers
@@ -1450,9 +1453,9 @@ class Post(models.Model):
         #4) question asked by me (todo: not "edited_by_me" ???)
         question_author = origin_post.author
         if EmailFeedSetting.objects.filter(
-            subscriber = question_author,
-            frequency = 'i',
-            feed_type = 'q_ask'
+            subscriber=question_author,
+            frequency='i',
+            feed_type='q_ask'
         ).exists():
             subscriber_set.add(question_author)
 
@@ -1466,9 +1469,9 @@ class Post(models.Model):
 
         if answer_authors:
             answer_subscribers = EmailFeedSetting.objects.filter_subscribers(
-                potential_subscribers = answer_authors,
-                frequency = 'i',
-                feed_type = 'q_ans',
+                potential_subscribers=answer_authors,
+                frequency='i',
+                feed_type='q_ans',
             )
             subscriber_set.update(answer_subscribers)
             #print 'answer subscribers: ', answer_subscribers
@@ -1944,7 +1947,7 @@ class Post(models.Model):
         if text is None:
             text = latest_rev.text
         if edited_at is None:
-            edited_at = datetime.datetime.now()
+            edited_at = timezone.now()
         if edited_by is None:
             raise Exception('edited_by is required')
 
@@ -2004,7 +2007,6 @@ class Post(models.Model):
 
         return latest_rev
 
-
     def __add_revision(
                     self,
                     author=None,
@@ -2478,7 +2480,7 @@ class AnonymousAnswer(AnonymousContent):
     question = models.ForeignKey(Post, related_name='anonymous_answers')
 
     def publish(self, user):
-        added_at = datetime.datetime.now()
+        added_at = timezone.now()
         try:
             user.assert_can_post_text(self.text)
 
