@@ -28,6 +28,9 @@ def patch_django():
         except ImportError:
             django_patches.fix_lazy_double_escape()
 
+    if major == 1 and minor > 5:
+        django_patches.add_hashcompat()
+
 def patch_coffin():
     """coffin before version 0.3.4
     does not have csrf_token template tag.
