@@ -9,8 +9,8 @@ Also this module includes the view listing all forum users.
 import askbot
 import calendar
 import collections
-import functools
 import datetime
+import functools
 import logging
 import math
 import os
@@ -34,7 +34,7 @@ from django.utils.translation import get_language
 from django.utils.translation import string_concat
 from django.utils.translation import ugettext as _
 from django.utils.translation import ungettext
-from django.utils import simplejson
+from django.utils import simplejson, timezone
 from django.utils.html import strip_tags as strip_all_tags
 from django.views.decorators import csrf
 
@@ -124,10 +124,10 @@ def show_users(request, by_group=False, group_id=None, group_slug=None):
         return HttpResponseRedirect(new_url)
 
     users = models.User.objects.exclude(
-                                    status='b'
+                                    askbot_profile__status='b'
                                 ).exclude(
                                     is_active=False
-                                )
+                                ).select_related('askbot_profile')
     group = None
     group_email_moderation_enabled = False
     user_acceptance_level = 'closed'
@@ -191,7 +191,7 @@ def show_users(request, by_group=False, group_id=None, group_slug=None):
             order_by_parameter = 'username'
         else:
             # default
-            order_by_parameter = '-reputation'
+            order_by_parameter = '-askbot_profile__reputation'
 
         objects_list = Paginator(
                             users.order_by(order_by_parameter),
@@ -202,7 +202,7 @@ def show_users(request, by_group=False, group_id=None, group_slug=None):
         sort_method = 'reputation'
         matching_users = models.get_users_by_text_query(search_query, users)
         objects_list = Paginator(
-                            matching_users.order_by('-reputation'),
+                            matching_users.order_by('-askbot_profile__reputation'),
                             askbot_settings.USERS_PAGE_SIZE
                         )
         base_url = request.path + '?name=%s&sort=%s&' % (search_query, sort_method)
@@ -411,7 +411,7 @@ def user_moderate(request, subject, context):
                                     user = subject,
                                     reputation_change = rep_delta,
                                     comment = comment,
-                                    timestamp = datetime.datetime.now(),
+                                    timestamp = timezone.now(),
                                 )
                 #reset form to preclude accidentally repeating submission
                 user_rep_form = forms.ChangeUserReputationForm()
@@ -768,8 +768,8 @@ def set_user_description(request):
         raise django_exceptions.PermissionDenied(message)
 
     if user_id == request.user.pk or request.user.is_admin_or_mod():
-        user.about = description
-        user.save()
+        user.askbot_profile.about = description
+        user.askbot_profile.save()
         return {'description_html': convert_text(description)}
 
     raise django_exceptions.PermissionDenied
@@ -1256,7 +1256,7 @@ def user_unsubscribe(request):
             #we use email too, in case the key changed
             user = models.User.objects.get(email=email)
         except models.User.DoesNotExist:
-            user = models.User.objects.get(email_key=key)
+            user = models.User.objects.get(askbot_profile__email_key=key)
         except models.User.DoesNotExist:
             result = 'bad_input'
         except models.User.MultipleObjectsReturned:
@@ -1460,7 +1460,7 @@ def groups(request, id = None, slug = None):
                                     )
 
     groups = groups.exclude_personal()
-    groups = groups.annotate(users_count=Count('user'))
+    groups = groups.annotate(users_count=Count('user_membership'))
 
     user_can_add_groups = request.user.is_authenticated() and \
             request.user.is_administrator_or_moderator()
